<?php
/**
 * Solar Services Theme Customizer
 *
 * @package Solar Services
 */

get_template_part('/inc/select/solar-services-category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function solar_services_customize_register( $wp_customize ) {

	function solar_services_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';


	// color site title
	$wp_customize->add_setting('solar_services_sitetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'solar_services_sitetitle_color', array(
	   'settings' => 'solar_services_sitetitle_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Title Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'solar_services_sanitize_checkbox',
	));
	$wp_customize->add_control( 'solar_services_title_enable', array(
	   'settings' => 'solar_services_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','solar-services'),
	   'type'      => 'checkbox'
	));


	//Theme Options
	$wp_customize->add_panel( 'solar_services_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'solar-services' ),
	) );

	// Header Section
	$wp_customize->add_section('solar_services_header_section', array(
        'title' => __('Header Section', 'solar-services'),
        'priority' => null,
		'panel' => 'solar_services_panel_area',
 	));

	// header topbg color
	$wp_customize->add_setting('solar_services_headertopbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headertopbg_color', array(
	   'settings' => 'solar_services_headertopbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Top BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// phone
	$wp_customize->add_setting('solar_services_phone_text',array(
		'default' => '800 5620 789',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_phone_text', array(
	   'settings' => 'solar_services_phone_text',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Phone Text', 'solar-services'),
	   'type'      => 'text'
	));

	// header phoneicon color
	$wp_customize->add_setting('solar_services_headerphoneicon_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerphoneicon_color', array(
	   'settings' => 'solar_services_headerphoneicon_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Phone Icon Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header phoneiconbg color
	$wp_customize->add_setting('solar_services_headerphoneiconbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerphoneiconbg_color', array(
	   'settings' => 'solar_services_headerphoneiconbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Phone Icon BG Color', 'solar-services'),
	   'type'      => 'color'
	));


	// header phonetext color
	$wp_customize->add_setting('solar_services_headerphonetext_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerphonetext_color', array(
	   'settings' => 'solar_services_headerphonetext_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Phone Text Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header phonehover color
	$wp_customize->add_setting('solar_services_headerphonehover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerphonehover_color', array(
	   'settings' => 'solar_services_headerphonehover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Phone Hover Color', 'solar-services'),
	   'type'      => 'color'
	));



	$wp_customize->add_setting('solar_services_email_text',array(
		'default' => 'admin@gmail.com',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_email_text', array(
	   'settings' => 'solar_services_email_text',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Email Text', 'solar-services'),
	   'type'      => 'text'
	));

	// header emailicon color
	$wp_customize->add_setting('solar_services_headeremailicon_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headeremailicon_color', array(
	   'settings' => 'solar_services_headeremailicon_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Email Icon Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header emailiconbg color
	$wp_customize->add_setting('solar_services_headeremailiconbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headeremailiconbg_color', array(
	   'settings' => 'solar_services_headeremailiconbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Email Icon BG Color', 'solar-services'),
	   'type'      => 'color'
	));


	// header emailtext color
	$wp_customize->add_setting('solar_services_headeremailtext_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headeremailtext_color', array(
	   'settings' => 'solar_services_headeremailtext_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Email Text Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header emailhover color
	$wp_customize->add_setting('solar_services_headeremailhover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headeremailhover_color', array(
	   'settings' => 'solar_services_headeremailhover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Email Hover Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_fb_link',array(
		'default' => '#',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_fb_link', array(
	   'settings' => 'solar_services_fb_link',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Facebook Link', 'solar-services'),
	   'type'      => 'url'
	));

	// header fbicon color
	$wp_customize->add_setting('solar_services_headerfbicon_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerfbicon_color', array(
	   'settings' => 'solar_services_headerfbicon_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Facebook Icon Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_twitt_link',array(
		'default' => '#',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_twitt_link', array(
	   'settings' => 'solar_services_twitt_link',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Twitter Link', 'solar-services'),
	   'type'      => 'url'
	));

	// header twitt color
	$wp_customize->add_setting('solar_services_headertwitt_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headertwitt_color', array(
	   'settings' => 'solar_services_headertwitt_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Twitter Icon Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_linked_link',array(
		'default' => '#',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_linked_link', array(
	   'settings' => 'solar_services_linked_link',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Linkdin Link', 'solar-services'),
	   'type'      => 'url'
	));

	// header Linkdin color
	$wp_customize->add_setting('solar_services_headerLinkdin_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerLinkdin_color', array(
	   'settings' => 'solar_services_headerLinkdin_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Linkdin Icon Color', 'solar-services'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('solar_services_insta_link',array(
		'default' => '#',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_insta_link', array(
	   'settings' => 'solar_services_insta_link',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Instagram Link', 'solar-services'),
	   'type'      => 'url'
	));

	// header Instagram color
	$wp_customize->add_setting('solar_services_headerInstagram_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerInstagram_color', array(
	   'settings' => 'solar_services_headerInstagram_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Instagram Icon Color', 'solar-services'),
	   'type'      => 'color'
	));


	// header iconsbg color
	$wp_customize->add_setting('solar_services_headericonsbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headericonsbg_color', array(
	   'settings' => 'solar_services_headericonsbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Icons BG Color', 'solar-services'),
	   'type'      => 'color'
	));


	// header iconshover color
	$wp_customize->add_setting('solar_services_headericonshover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headericonshover_color', array(
	   'settings' => 'solar_services_headericonshover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Icons Hover Color', 'solar-services'),
	   'type'      => 'color'
	));



	// header menusbg color
	$wp_customize->add_setting('solar_services_headermenusbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headermenusbg_color', array(
	   'settings' => 'solar_services_headermenusbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Menu BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header menu color
	$wp_customize->add_setting('solar_services_headermenu_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headermenu_color', array(
	   'settings' => 'solar_services_headermenu_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Menus Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header menuhover color
	$wp_customize->add_setting('solar_services_headermenuhover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headermenuhover_color', array(
	   'settings' => 'solar_services_headermenuhover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Menus Hover Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header submenu color
	$wp_customize->add_setting('solar_services_headersubmenu_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headersubmenu_color', array(
	   'settings' => 'solar_services_headersubmenu_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('SubMenus Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header submenuhover color
	$wp_customize->add_setting('solar_services_headersubmenuhover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headersubmenuhover_color', array(
	   'settings' => 'solar_services_headersubmenuhover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('SubMenus Hover Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header submenubg color
	$wp_customize->add_setting('solar_services_headersubmenubg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headersubmenubg_color', array(
	   'settings' => 'solar_services_headersubmenubg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('SubMenus BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header submenuborder color
	$wp_customize->add_setting('solar_services_headersubmenuborder_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headersubmenuborder_color', array(
	   'settings' => 'solar_services_headersubmenuborder_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('SubMenus Border Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header btn text
	$wp_customize->add_setting('solar_services_headerbutton_txt',array(
		'default' => 'Contact Us',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbutton_txt', array(
	   'settings' => 'solar_services_headerbutton_txt',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Text', 'solar-services'),
	   'type'      => 'text'
	));

	// header btn link
	$wp_customize->add_setting('solar_services_headerbutton_link',array(
		'default' => '#',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbutton_link', array(
	   'settings' => 'solar_services_headerbutton_link',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Link', 'solar-services'),
	   'type'      => 'text'
	));



	// header btntext color
	$wp_customize->add_setting('solar_services_headerbtntext_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbtntext_color', array(
	   'settings' => 'solar_services_headerbtntext_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Text Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header btntextborder color
	$wp_customize->add_setting('solar_services_headerbtntextborder_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbtntextborder_color', array(
	   'settings' => 'solar_services_headerbtntextborder_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Border Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header btntextbg color
	$wp_customize->add_setting('solar_services_headerbtntextbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbtntextbg_color', array(
	   'settings' => 'solar_services_headerbtntextbg_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Text BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// header btntexthover color
	$wp_customize->add_setting('solar_services_headerbtntexthover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headerbtntexthover_color', array(
	   'settings' => 'solar_services_headerbtntexthover_color',
	   'section'   => 'solar_services_header_section',
	   'label' => __('Button Text Hover Color', 'solar-services'),
	   'type'      => 'color'
	));


	// Home Category Dropdown Section
	$wp_customize->add_section('solar_services_one_cols_section',array(
		'title'	=> __('Slider Section','solar-services'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1600 x 850).','solar-services'),
		'priority'	=> null,
		'panel' => 'solar_services_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'solar_services_slidersection', array(
		'default'	=> '0',
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new solar_services_Category_Dropdown_Custom_Control( $wp_customize, 'solar_services_slidersection', array(
		'section' => 'solar_services_one_cols_section',
		'settings'   => 'solar_services_slidersection',
	) ) );

	//Hide Section
	$wp_customize->add_setting('solar_services_hide_categorysec',array(
		'default' => false,
		'sanitize_callback' => 'solar_services_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'solar_services_hide_categorysec', array(
	   'settings' => 'solar_services_hide_categorysec',
	   'section'   => 'solar_services_one_cols_section',
	   'label'     => __('Check To Enable This Section','solar-services'),
	   'type'      => 'checkbox'
	));

	// no. of slider to show
	$wp_customize->add_setting( 'solar_services_slider_count', array(
	  	'capability' => 'edit_theme_options',
	  	'sanitize_callback' => 'solar_services_sanitize_number_absint',
	  	'default' => 4,
	) );
	$wp_customize->add_control( 'solar_services_slider_count', array(
	  	'settings' => 'solar_services_slider_count',
	  	'type' => 'number',
	  	'section' => 'solar_services_one_cols_section',
	  	'label' => __( 'Number Of Slide To Show','solar-services'),
	) );

	// header slidertitle color
	$wp_customize->add_setting('solar_services_slidertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_slidertitle_color', array(
	   'settings' => 'solar_services_slidertitle_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Title Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_button_text',array(
		'default' => 'Our Service',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_button_text', array(
	   'settings' => 'solar_services_button_text',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Add Button 1 Text', 'solar-services'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('solar_services_button_text2',array(
		'default' => 'More About Us',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_button_text2', array(
	   'settings' => 'solar_services_button_text2',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Add Button 2 Text', 'solar-services'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('solar_services_button_text2link',array(
		'default' => '#',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_button_text2link', array(
	   'settings' => 'solar_services_button_text2link',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Add Button 2 Text Link', 'solar-services'),
	   'type'      => 'text'
	));


	// slider btntext color
	$wp_customize->add_setting('solar_services_sliderbtntext_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtntext_color', array(
	   'settings' => 'solar_services_sliderbtntext_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 1 Text Color', 'solar-services'),
	   'type'      => 'color'
	));


	// slider btnbg color
	$wp_customize->add_setting('solar_services_sliderbtnbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtnbg_color', array(
	   'settings' => 'solar_services_sliderbtnbg_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 1 BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// slider btnborder color
	$wp_customize->add_setting('solar_services_sliderbtnborder_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtnborder_color', array(
	   'settings' => 'solar_services_sliderbtnborder_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 1 Border Color', 'solar-services'),
	   'type'      => 'color'
	));


	// slider btntext2 color
	$wp_customize->add_setting('solar_services_sliderbtntext2_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtntext2_color', array(
	   'settings' => 'solar_services_sliderbtntext2_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 2 Text Color', 'solar-services'),
	   'type'      => 'color'
	));


	// slider btnbg2 color
	$wp_customize->add_setting('solar_services_sliderbtnbg2_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtnbg2_color', array(
	   'settings' => 'solar_services_sliderbtnbg2_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 2 BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// slider btnborder2 color
	$wp_customize->add_setting('solar_services_sliderbtnborder2_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_sliderbtnborder2_color', array(
	   'settings' => 'solar_services_sliderbtnborder2_color',
	   'section'   => 'solar_services_one_cols_section',
	   'label' => __('Button 2 Border Color', 'solar-services'),
	   'type'      => 'color'
	));




	// Features Section
	$wp_customize->add_section('solar_services_feature_section', array(
		'title'	=> __('Features Section','solar-services'),
		'description'	=> __('Select Pages from the dropdown for blog.','solar-services'),
		'priority'	=> null,
		'panel' => 'solar_services_panel_area',
	));


	// Add a category dropdown
	$wp_customize->add_setting( 'solar_services_feature_cat', array(
		'default'	=> '0',
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new solar_services_Category_Dropdown_Custom_Control( $wp_customize, 'solar_services_feature_cat', array(
		'section' => 'solar_services_feature_section',
		'settings'   => 'solar_services_feature_cat',
	) ) );

	$wp_customize->add_setting('solar_services_disabled_feature_pgboxes',array(
		'default' => false,
		'sanitize_callback' => 'solar_services_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'solar_services_disabled_feature_pgboxes', array(
	   'settings' => 'solar_services_disabled_feature_pgboxes',
	   'section'   => 'solar_services_feature_section',
	   'label'     => __('Check To Enable This Section','solar-services'),
	   'type'      => 'checkbox'
	));

	// feature leftboxbg color
	$wp_customize->add_setting('solar_services_featureleftboxbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftboxbg_color', array(
	   'settings' => 'solar_services_featureleftboxbg_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Box BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature leftheading color
	$wp_customize->add_setting('solar_services_featureleftheading',array(
		'default' => 'Our Facility',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftheading', array(
	   'settings' => 'solar_services_featureleftheading',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Heading', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftheading color
	$wp_customize->add_setting('solar_services_featureleftheading_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftheading_color', array(
	   'settings' => 'solar_services_featureleftheading_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Heading Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature leftdescription color
	$wp_customize->add_setting('solar_services_featureleftdescription',array(
		'default' => 'The sun provides us with free energy, place solar panels on roof. solar cell, solar module manufacturing facilities are considerable. we must go above our customer expectations during interaction.','solar-services',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftdescription', array(
	   'settings' => 'solar_services_featureleftdescription',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Description', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftdescription color
	$wp_customize->add_setting('solar_services_featureleftdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftdescription_color', array(
	   'settings' => 'solar_services_featureleftdescription_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Description Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature leftlist1 color
	$wp_customize->add_setting('solar_services_featureleftlist1',array(
		'default' => 'Best Energy Solution',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftlist1', array(
	   'settings' => 'solar_services_featureleftlist1',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left List 1', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftlist2 color
	$wp_customize->add_setting('solar_services_featureleftlist2',array(
		'default' => 'End-To-End Services',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftlist2', array(
	   'settings' => 'solar_services_featureleftlist2',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left List 2', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftlist3 color
	$wp_customize->add_setting('solar_services_featureleftlist3',array(
		'default' => 'Global Expertise',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftlist3', array(
	   'settings' => 'solar_services_featureleftlist3',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left List 3', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftlist4 color
	$wp_customize->add_setting('solar_services_featureleftlist4',array(
		'default' => 'Certified Engineers',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftlist4', array(
	   'settings' => 'solar_services_featureleftlist4',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left List 4', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftlist color
	$wp_customize->add_setting('solar_services_featureleftlist_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftlist_color', array(
	   'settings' => 'solar_services_featureleftlist_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left List Color', 'solar-services'),
	   'type'      => 'color'
	));


	// feature leftbtntext color
	$wp_customize->add_setting('solar_services_featureleftbtntext',array(
		'default' => 'Our Service',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftbtntext', array(
	   'settings' => 'solar_services_featureleftbtntext',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Button Text', 'solar-services'),
	   'type'      => 'text'
	));

	// feature leftbtnlink color
	$wp_customize->add_setting('solar_services_featureleftbtnlink',array(
		'default' => '#',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftbtnlink', array(
	   'settings' => 'solar_services_featureleftbtnlink',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Button Link', 'solar-services'),
	   'type'      => 'text'
	));


	// feature leftbtntxt color
	$wp_customize->add_setting('solar_services_featureleftbtntxt_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftbtntxt_color', array(
	   'settings' => 'solar_services_featureleftbtntxt_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Button Text Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature leftbtnbg color
	$wp_customize->add_setting('solar_services_featureleftbtnbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftbtnbg_color', array(
	   'settings' => 'solar_services_featureleftbtnbg_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Button BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature leftbtnborder color
	$wp_customize->add_setting('solar_services_featureleftbtnborder_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureleftbtnborder_color', array(
	   'settings' => 'solar_services_featureleftbtnborder_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Left Button Border Color', 'solar-services'),
	   'type'      => 'color'
	));




	// feature bg color
	$wp_customize->add_setting('solar_services_featurebg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featurebg_color', array(
	   'settings' => 'solar_services_featurebg_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature boxbg color
	$wp_customize->add_setting('solar_services_featureboxbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featureboxbg_color', array(
	   'settings' => 'solar_services_featureboxbg_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Box BG Color', 'solar-services'),
	   'type'      => 'color'
	));

	// feature head color
	$wp_customize->add_setting('solar_services_featurehead_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_featurehead_color', array(
	   'settings' => 'solar_services_featurehead_color',
	   'section'   => 'solar_services_feature_section',
	   'label' => __('Heading Color', 'solar-services'),
	   'type'      => 'color'
	));

      // Google Fonts
      $wp_customize->add_section( 'solar_services_google_fonts_section', array(
      'title'       => __( 'Google Fonts', 'solar-services' ),
      'priority'    => 24,
    ) );

    $font_choices = array(
      'Kaushan Script:' => 'Kaushan Script',
      'Emilys Candy:' => 'Emilys Candy',
      'Poppins:0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900' => 'Poppins',
      'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
      'Open Sans:400italic,700italic,400,700' => 'Open Sans',
      'Oswald:400,700' => 'Oswald',
      'Playfair Display:400,700,400italic' => 'Playfair Display',
      'Montserrat:400,700' => 'Montserrat',
      'Raleway:400,700' => 'Raleway',
      'Droid Sans:400,700' => 'Droid Sans',
      'Lato:400,700,400italic,700italic' => 'Lato',
      'Arvo:400,700,400italic,700italic' => 'Arvo',
      'Lora:400,700,400italic,700italic' => 'Lora',
      'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
      'Oxygen:400,300,700' => 'Oxygen',
      'PT Serif:400,700' => 'PT Serif',
      'PT Sans:400,700,400italic,700italic' => 'PT Sans',
      'PT Sans Narrow:400,700' => 'PT Sans Narrow',
      'Cabin:400,700,400italic' => 'Cabin',
      'Fjalla One:400' => 'Fjalla One',
      'Francois One:400' => 'Francois One',
      'Josefin Sans:400,300,600,700' => 'Josefin Sans',
      'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
      'Arimo:400,700,400italic,700italic' => 'Arimo',
      'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
      'Bitter:400,700,400italic' => 'Bitter',
      'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
      'Roboto:400,400italic,700,700italic' => 'Roboto',
      'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
      'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
      'Roboto Slab:400,700' => 'Roboto Slab',
      'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
      'Rokkitt:400' => 'Rokkitt',
    );

    $wp_customize->add_setting( 'solar_services_headings_fonts', array(
      'sanitize_callback' => 'solar_services_sanitize_fonts',
    ));
    $wp_customize->add_control( 'solar_services_headings_fonts', array(
      'type' => 'select',
      'description' => __('Select your desired font for the headings.', 'solar-services'),
      'section' => 'solar_services_google_fonts_section',
      'choices' => $font_choices
    ));

    $wp_customize->add_setting( 'solar_services_body_fonts', array(
      'sanitize_callback' => 'solar_services_sanitize_fonts'
    ));
    $wp_customize->add_control( 'solar_services_body_fonts', array(
      'type' => 'select',
      'description' => __( 'Select your desired font for the body.', 'solar-services' ),
      'section' => 'solar_services_google_fonts_section',
      'choices' => $font_choices
    ));

	// blog Section
	$wp_customize->add_section('solar_services_below_slider_section', array(
		'title'	=> __('Blog Section','solar-services'),
		'description'	=> __('Select Pages from the dropdown for Blog.','solar-services'),
		'priority'	=> null,
		'panel' => 'solar_services_panel_area',
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'solar_services_blog_cat', array(
		'default'	=> '0',
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new solar_services_Category_Dropdown_Custom_Control( $wp_customize, 'solar_services_blog_cat', array(
		'section' => 'solar_services_below_slider_section',
		'settings'   => 'solar_services_blog_cat',
	) ) );


	// no. of blog to show
	$wp_customize->add_setting( 'solar_services_blog_count', array(
	  	'capability' => 'edit_theme_options',
	  	'sanitize_callback' => 'solar_services_sanitize_number_absint',
	  	'default' => 3,
	) );
	$wp_customize->add_control( 'solar_services_blog_count', array(
	  	'settings' => 'solar_services_blog_count',
	  	'type' => 'number',
	  	'section' => 'solar_services_below_slider_section',
	  	'label' => __( 'Number Of blog To Show','solar-services'),
	) );

	$wp_customize->add_setting('solar_services_headingtext1',array(
		'default' => 'Our Blog',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headingtext1', array(
	   'settings' => 'solar_services_headingtext1',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Heading', 'solar-services'),
	   'type'      => 'text'
	));

	// blog heading color
	$wp_customize->add_setting('solar_services_blogheading_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogheading_color', array(
	   'settings' => 'solar_services_blogheading_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Heading Color', 'solar-services'),
	   'type'      => 'color'
	));


	$wp_customize->add_setting('solar_services_headingtext_para',array(
		'default' => 'Latest From Our Blog',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_headingtext_para', array(
	   'settings' => 'solar_services_headingtext_para',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Sub Heading', 'solar-services'),
	   'type'      => 'text'
	));

	// blog headingcontent color
	$wp_customize->add_setting('solar_services_blogheadingcontent_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogheadingcontent_color', array(
	   'settings' => 'solar_services_blogheadingcontent_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Sub Heading Content', 'solar-services'),
	   'type'      => 'color'
	));



	// blog boxbg color
	$wp_customize->add_setting('solar_services_blogboxbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogboxbg_color', array(
	   'settings' => 'solar_services_blogboxbg_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Box BG Color', 'solar-services'),
	   'type'      => 'color'
	));


	// blog title color
	$wp_customize->add_setting('solar_services_blogtitle_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogtitle_color', array(
	   'settings' => 'solar_services_blogtitle_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Title Color', 'solar-services'),
	   'type'      => 'color'
	));

	// blog description color
	$wp_customize->add_setting('solar_services_blogdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogdescription_color', array(
	   'settings' => 'solar_services_blogdescription_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Description Color', 'solar-services'),
	   'type'      => 'color'
	));

	// blog btn text color
	$wp_customize->add_setting('solar_services_blogebtntxt_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogebtntxt_color', array(
	   'settings' => 'solar_services_blogebtntxt_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Button Text Color', 'solar-services'),
	   'type'      => 'color'
	));

	// blog btn bg color
	$wp_customize->add_setting('solar_services_blogebtnbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_blogebtnbg_color', array(
	   'settings' => 'solar_services_blogebtnbg_color',
	   'section'   => 'solar_services_below_slider_section',
	   'label' => __('Button BG Color', 'solar-services'),
	   'type'      => 'color'
	));



	// Footer Section
    // footer bg color
	$wp_customize->add_setting('solar_services_footerbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footerbg_color', array(
	   'settings' => 'solar_services_footerbg_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('BG Color', 'solar-services'),
	   'type'      => 'color'
	));

    // footer copyright
	$wp_customize->add_section('solar_services_footer', array(
		'title'	=> __('Footer Section','solar-services'),
		'priority'	=> null,
		'panel' => 'solar_services_panel_area',
	));

	$wp_customize->add_setting('solar_services_copyright_line',array(
		'default' => 'Solar Services WordPress Theme',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'solar_services_copyright_line', array(
	   'section' 	=> 'solar_services_footer',
	   'label'	 	=> __('Copyright Line','solar-services'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));



 	// footer coypright color
	$wp_customize->add_setting('solar_services_footercoypright_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footercoypright_color', array(
	   'settings' => 'solar_services_footercoypright_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('coypright Color', 'solar-services'),
	   'type'      => 'color'
	));

	// footer coyprightbg color
	$wp_customize->add_setting('solar_services_footercoyprightbg_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footercoyprightbg_color', array(
	   'settings' => 'solar_services_footercoyprightbg_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('coypright BG Color', 'solar-services'),
	   'type'      => 'color'
	));


	// footer heading color
	$wp_customize->add_setting('solar_services_footerheading_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footerheading_color', array(
	   'settings' => 'solar_services_footerheading_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('Heading Color', 'solar-services'),
	   'type'      => 'color'
	));


	// footer list color
	$wp_customize->add_setting('solar_services_footerlist_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footerlist_color', array(
	   'settings' => 'solar_services_footerlist_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('List Color', 'solar-services'),
	   'type'      => 'color'
	));


	// footer listicon color
	$wp_customize->add_setting('solar_services_footerlisticon_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footerlisticon_color', array(
	   'settings' => 'solar_services_footerlisticon_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('List Icon Color', 'solar-services'),
	   'type'      => 'color'
	));

	// footer listhover color
	$wp_customize->add_setting('solar_services_footerlisthover_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footerlisthover_color', array(
	   'settings' => 'solar_services_footerlisthover_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('List Hover Color', 'solar-services'),
	   'type'      => 'color'
	));

	// footer text color
	$wp_customize->add_setting('solar_services_footertext_color',array(
		'default' => '',
		'sanitize_callback' => 'solarservices_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'solar_services_footertext_color', array(
	   'settings' => 'solar_services_footertext_color',
	   'section'   => 'solar_services_footer',
	   'label' => __('Text Color', 'solar-services'),
	   'type'      => 'color'
	));




}
add_action( 'customize_register', 'solar_services_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function solar_services_customize_preview_js() {
	wp_enqueue_script( 'solar_services_customizer',get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'solar_services_customize_preview_js' );
